//[mahjong-utils](../../../index.md)/[mahjongutils.models.hand](../index.md)/[ChitoiHandPattern](index.md)/[pairs](pairs.md)

# pairs

[common]\
open override val [pairs](pairs.md): [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Tile](../../mahjongutils.models/-tile/index.md)&gt;

已有对子
